<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DeselectAll</name>
    <message>
        <location filename="../DeselectAllInit.js" line="+2"/>
        <source>&amp;Deselect All</source>
        <translation>Zr&amp;ušit celý výběr</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Deselect all entities</source>
        <translation>Zrušit výběr objektů</translation>
    </message>
</context>
</TS>
